@@ -19,7 +19,7 @@
  * USA
  *
  * --------------------------------------------------------------------------
- * $Id: RouteBuilderComponent.java 20996 2011-03-14 20:05:08Z alitokmen $
+ * $Id: RouteBuilderComponent.java 21309 2011-05-25 10:48:03Z ardaaydin $
  * --------------------------------------------------------------------------
  */
 package org.ow2.jonas.camel.component;
@@ -181,7 +181,15 @@ public abstract class RouteBuilderComponent extends RouteBuilder {
 
             // Start a new Camel context for the application
             this.logger.debug("Starting CAMEL context for route {0}", this.getRouteName());
-            this.camelContextName = this.camelService.startNewContext(this.bundleContext);
+            /* 
+             * If camelContextName is not overriden by a child class
+             * or there is no already existing Camel context with overriden camelContextName
+             * then create new Camel context
+            */
+            if(null==this.camelContextName || !this.camelService.getContextNames().contains(this.camelContextName)) {
+                this.camelContextName = this.camelService.startNewContext(this.bundleContext);
+            }
+            this.logger.info("Starting CAMEL context name for route {0}", this.camelContextName);
             DefaultCamelContext camelContext = (DefaultCamelContext) this.camelService.getCamelContext(this.camelContextName);
 
             // Add registry entries
