@@ -19,7 +19,7 @@
  * USA
  *
  * --------------------------------------------------------------------------
- * $Id: CamelServiceTest.java 20427 2010-10-07 11:34:42Z alitokmen $
+ * $Id: CamelServiceTest.java 20667 2011-01-03 17:07:21Z alitokmen $
  * --------------------------------------------------------------------------
  */
 package org.ow2.jonas.camel.service.test;
@@ -34,10 +34,9 @@ import junit.framework.TestCase;
 import org.apache.activemq.ActiveMQConnectionFactory;
 import org.apache.camel.CamelContext;
 import org.apache.camel.Endpoint;
-import org.apache.camel.builder.RouteBuilder;
 import org.apache.camel.component.jms.JmsComponent;
 import org.apache.camel.impl.ServiceSupport;
-import org.ow2.jonas.camel.service.api.ICamelService;
+import org.osgi.framework.BundleContext;
 import org.ow2.jonas.camel.service.impl.CamelService;
 
 /**
@@ -45,6 +44,11 @@ import org.ow2.jonas.camel.service.impl.CamelService;
  */
 public class CamelServiceTest extends TestCase {
 
+    /**
+     * Bundle context instance used by this test.
+     */
+    private BundleContext bundleContext;
+
     /**
      * Camel service instance used by this test.
      */
@@ -56,7 +60,8 @@ public class CamelServiceTest extends TestCase {
     @Override
     protected void setUp() throws Exception {
         super.setUp();
-        this.camelService = new CamelService(new MockBundleContext());
+        this.bundleContext = new MockBundleContext();
+        this.camelService = new CamelService(this.bundleContext);
         this.camelService.start();
     }
 
@@ -81,7 +86,7 @@ public class CamelServiceTest extends TestCase {
         Assert.assertTrue(this.camelService.getContextNames().isEmpty());
 
         // start new context
-        final String contextName = this.camelService.startNewContext();
+        final String contextName = this.camelService.startNewContext(this.bundleContext);
 
         // check context names contains new context
         Assert.assertEquals(1, this.camelService.getContextNames().size());
@@ -105,7 +110,7 @@ public class CamelServiceTest extends TestCase {
         Assert.assertTrue(this.camelService.getContextNames().isEmpty());
 
         // start new context
-        final String contextName = this.camelService.startNewContext();
+        final String contextName = this.camelService.startNewContext(this.bundleContext);
 
         // get camelContext:
         final CamelContext camelContext = this.camelService.getCamelContext(contextName);
@@ -125,7 +130,7 @@ public class CamelServiceTest extends TestCase {
      */
     public void testStartNewContext() throws Exception {
         // start new context
-        final String contextName = this.camelService.startNewContext();
+        final String contextName = this.camelService.startNewContext(this.bundleContext);
 
         Assert.assertNotNull(contextName);
 
@@ -145,7 +150,7 @@ public class CamelServiceTest extends TestCase {
      */
     public void testStartAndGetNewContext() throws Exception {
         // start new context
-        final CamelContext camelContext = this.camelService.startAndGetNewContext();
+        final CamelContext camelContext = this.camelService.startAndGetNewContext(this.bundleContext);
 
         Assert.assertNotNull(camelContext);
 
@@ -162,7 +167,7 @@ public class CamelServiceTest extends TestCase {
      */
     public void testStop() throws Exception {
         // start new context
-        final String contextName = this.camelService.startNewContext();
+        final String contextName = this.camelService.startNewContext(this.bundleContext);
 
         Assert.assertNotNull(contextName);
 
@@ -177,80 +182,6 @@ public class CamelServiceTest extends TestCase {
         Assert.assertTrue(((ServiceSupport) camelContext).isStopped());
     }
 
-    /**
-     * Test method for
-     * {@link org.ow2.jonas.camel.service.api.ICamelService#addRoutes(org.apache.camel.builder.RouteBuilder, java.lang.String)}
-     * .
-     * 
-     * @throws Exception
-     */
-     /*
-    public void testAddRoutes() throws Exception {
-        // start new context
-        final String contextName = this.camelService.startNewContext();
-
-        Assert.assertNotNull(contextName);
-
-        // get camelContext
-        final CamelContext camelContext = this.camelService.getCamelContext(contextName);
-
-        Assert.assertTrue(camelContext.getRoutes().isEmpty());
-
-        // add route
-        this.camelService.addRoutes(new RouteBuilder() {
-            @Override
-            public void configure() throws Exception {
-                this.from("direct:a").to("direct:b");
-                this.from("direct:c").to("direct:d");
-            }
-        }, contextName);
-
-        // check routes are added
-        Assert.assertEquals(2, camelContext.getRoutes().size());
-    }
-     */
-
-    /**
-     * Test method for
-     * {@link org.ow2.jonas.camel.service.api.ICamelService#getRoutes(java.lang.String)}
-     * .
-     * 
-     * @throws Exception
-     */
-     /*
-    public void testGetRouteDefinitions() throws Exception {
-        // start new context
-        final String contextName = this.camelService.startNewContext();
-
-        Assert.assertNotNull(contextName);
-
-        // get routeDefinitions
-        Assert.assertTrue(this.camelService.getRouteDefinitions(contextName).isEmpty());
-
-        // add route
-        this.camelService.addRoutes(new RouteBuilder() {
-            @Override
-            public void configure() throws Exception {
-                this.from("direct:a").to("direct:b");
-                this.from("direct:c").to("direct:d");
-            }
-        }, contextName);
-
-        // check routes are added
-        Assert.assertEquals(2, this.camelService.getRouteDefinitions(contextName).size());
-    }
-     */
-
-    /**
-     * Test method for
-     * {@link org.ow2.jonas.camel.service.api.ICamelService#getProducerTemplate(java.lang.String)}.
-     */
-     /*
-    public void testGetProducerTemplate() {
-        Assert.fail("Not yet implemented");
-    }
-     */
-
     /**
      * Test method for
      * {@link org.ow2.jonas.camel.service.api.ICamelService#addRegistry(java.io.InputStream, java.lang.String)}
@@ -262,7 +193,7 @@ public class CamelServiceTest extends TestCase {
         InputStream stream = Thread.currentThread().getContextClassLoader().getResourceAsStream("registry.xml");
 
         // start new context
-        final String contextName = this.camelService.startNewContext();
+        final String contextName = this.camelService.startNewContext(this.bundleContext);
 
         Assert.assertNotNull(contextName);
 
@@ -291,7 +222,7 @@ public class CamelServiceTest extends TestCase {
         InputStream stream = Thread.currentThread().getContextClassLoader().getResourceAsStream("registry.xml");
 
         // start new context
-        final String contextName = this.camelService.startNewContext();
+        final String contextName = this.camelService.startNewContext(this.bundleContext);
 
         Assert.assertNotNull(contextName);
 
@@ -313,12 +244,11 @@ public class CamelServiceTest extends TestCase {
 
     /**
      * Test method for
-     * {@link org.ow2.jonas.camel.service.api.ICamelService#addComponent(java.lang.String, org.apache.camel.Component, java.lang.String)}.
+     * {@link org.ow2.jonas.camel.service.api.ICamelService#addComponent(java.lang.String, org.apache.camel.Component, java.lang.String)}
+     * .
      */
-     /*
-    public void testAddComponent() {
-        Assert.fail("Not yet implemented");
-    }
+    /*
+     * public void testAddComponent() { Assert.fail("Not yet implemented"); }
      */
 
 }
